<?php

    /*
     * Plugin Name: In8Sync - NetSuite WooCommerce Integration
     * Plugin URI: https://in8sync.com/netsuite-wordpress-woocommerce-plugins/
     * Description: The In8Sync NetSuite WordPress WooCommerce Integration Plugin helps manage data syncing between NetSuite, WordPress and WooCommerce.
     * Version: 3.2.16
     * Author: In8Sync
     * Author URI: https://www.in8sync.com
     */

    if (!defined('ABSPATH')) {
        exit; // Exit if accessed directly
    }

    add_filter('http_request_args', function($r, $url){
      if( preg_match('/netsuite\.com/i', $url) ){
       $r['user-agent'] = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/56.0.2924.87 Safari/537.36';
      }
      return $r;
     }, 10, 2);


    //check if PHP ERRORS NEED TO BE ENABLED
    $debugging_level = get_option('in8_tab_general');
    if (isset($debugging_level['debug']['debug_level']) && $debugging_level['debug']['debug_level'] == 3) {
        ini_set('display_startup_errors', 1);
        ini_set('display_errors', 1);
        error_reporting(-1);
    }

    //plugins load hook
    add_action('plugins_loaded', 'init_in8_sync_plugin', 1);

    function init_in8_sync_plugin() {

        DEFINE("IN8_MAIN_DIR", plugin_dir_path(__FILE__));
        DEFINE("IN8_MAIN_URL", plugin_dir_url(__FILE__));

        require_once IN8_MAIN_DIR . "/code/in8sync-includes.php";
    }

    //run the install scripts upon plugin activation
    register_activation_hook(__FILE__, 'installIn8Plugin');

    //uninstall dependent plugins
    register_deactivation_hook(__FILE__, 'uninstallAllIn8Plugins');

    //function for creating log table "in8sync_log"
    function installIn8Plugin() {

        //create log database table
        global $wpdb;
        $table_name = $wpdb->prefix . "in8sync_log";
        $charset_collate = '';

        if (!empty($wpdb->charset)) {
            $charset_collate = "DEFAULT CHARACTER SET {$wpdb->charset}";
        }

        if (!empty($wpdb->collate)) {
            $charset_collate .= " COLLATE {$wpdb->collate}";
        }
        // check if table empty
        if ($wpdb->get_var("show tables like '$table_name'") != $table_name) {
            require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
            $sql = "CREATE TABLE `" . $table_name . "` (
                   `id` int(11) NOT NULL AUTO_INCREMENT,
                    `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                    `operation` varchar(100) NOT NULL,
                    `status` tinyint(4) NOT NULL,
                    `notes` text NOT NULL,
                    `woo_object_id` int(11) NULL,
                    PRIMARY KEY (`id`)
                  ) $charset_collate;";
            dbDelta($sql);
        }
    }

    function uninstallAllIn8Plugins() {

        //deactivate all dependent plugins
        $dependent_plugins = [
            'in8sync-customers/in8sync-customers.php',
            'in8sync-locator/in8sync-locator.php',
            'in8sync-inventory/in8sync-inventory.php',
            'in8sync-products/in8sync-products.php',
            'in8sync-salesorder/in8sync-salesorder.php'
        ];
        foreach ($dependent_plugins as $dependent_plugin) {
            deactivate_plugins(plugin_dir_path(__DIR__) . $dependent_plugin);
        }
    }

//    add_action('admin_init', 'in8_activate_updates');
    function in8_activate_updates() {
        require_once (IN8_MAIN_DIR . '/code/in8-update.php');

        $plugin_data = get_plugin_data(__FILE__);
        if (isset($plugin_data['Version'])) {
            $plugin_current_version = $plugin_data['Version'];
        } else {
            $plugin_current_version = '3.0';
        }
        $plugin_remote_path = 'https://secure.in8sync.com/update/currentversion.php';
        $plugin_slug = plugin_basename(__FILE__);
        new in8_wp_auto_update($plugin_current_version, $plugin_remote_path, $plugin_slug);
    }

    add_filter('manage_edit-shop_order_columns', 'MY_COLUMNS_FUNCTION');

    function MY_COLUMNS_FUNCTION($columns) {
        $new_columns = (is_array($columns)) ? $columns : array();
        //unset($new_columns['order_actions']);

        //edit this for you column(s)
        //all of your columns will be added before the actions column
        $new_columns['ns_order'] = 'NetSuite Order ID';
        //stop editing

        //$new_columns['order_actions'] = $columns['order_actions'];
        return $new_columns;
    }

    add_action('manage_shop_order_posts_custom_column', 'MY_COLUMNS_VALUES_FUNCTION', 2);

    function MY_COLUMNS_VALUES_FUNCTION($column) {
        global $post;
        $data = get_post_meta($post->ID, 'salesordernumber', TRUE);
        $id = get_post_meta($post->ID, 'internalid', TRUE);
	    $settings = IN8_Settings::getTabSettings('in8_tab_general', 'ns_api_creds');
	    $url = $settings['restlet_url'];
	    if( !empty($url) && !empty($id) ){
		    $parse = parse_url($url);
		    $order_link = 'https://'.$parse['host'].'/app/accounting/transactions/salesord.nl?id='.$id.'&whence=';
		    $order_link = str_replace('restlets.api', 'app', $order_link);
		    $order_link = apply_filters('in8sync_so_ns_url', $order_link, $id, $post->ID);
		    $data = "<a target='_blank' href='{$order_link}'>{$data}</a>";
	    }

        //start editing, I was saving my fields for the orders as custom post meta
        //if you did the same, follow this code
        if ($column == 'ns_order') {
            echo $data;
        }

        //stop editing
    } 
    
    // Try to connect to NetSuite
    add_action('wp_ajax_In8_Test_NS_Connection', 'testNetSuiteConnection');

    function testNetSuiteConnection() {
        
        $netsuite_connection = new NetsuiteConnection('0', 'customerforms', $_POST['account'], $_POST['token_id'], $_POST['token_secret'], $_POST['restlet_url']);
        $netsuite_connection_resp = $netsuite_connection->doRequest();
        
        if (isset($netsuite_connection_resp['success']) && $netsuite_connection_resp['success'] == 1 && !empty($netsuite_connection_resp['data'])) {
            $template = 'NetSuite connected successfully!';
        } else {
            $template = 'The connection with NetSuite cannot be established. Please check the account number, tokens and RESTlet URL.';
        }

        die($template);
    }